@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 """
-Copyright (c) 2013,2014 Fraunhofer FKIE
+Copyright (c) 2013-2015 Fraunhofer FKIE
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
@@ -11,6 +11,9 @@ are met:
  * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.
+ * Neither the name of the Fraunhofer organization nor the names of its
+   contributors may be used to endorse or promote products derived from
+   this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -113,6 +116,11 @@ dependencies with the COMPONENTS keyword. This is shorter than
 multiple find_package() calls, but does not work for system dependencies.
 """
 ),
+"UNKNOWN_PACKAGE" : ("unknown package '%(pkg)s'",
+"""\
+You have listed a package which is neither a catkin package nor a known system
+dependency.
+"""),
 "MISSING_CATKIN_DEPEND" : ("%(type)s_depend '%(pkg)s' is not listed in catkin_package()",
 """\
 You have specified a catkin run dependency but failed to list
@@ -250,6 +258,12 @@ catkin_package() command, but that path is not mentioned in any
 include_directories() call.
 """
 ),
+"DUPLICATE_BUILD_INCLUDE" : ("duplicate include path ${%(pkg)s_INCLUDE_DIRS}",
+"""\
+Include paths of packages listed in the find_package(catkin) command are added implicitly
+by the ${catkin_INCLUDE_DIRS} variable. There is no need to add it a second time.
+"""
+),
 "AMBIGUOUS_BUILD_INCLUDE" : ("include paths '%(path)s' and '%(parent_path)s' are ambiguous",
 """\
 You have used two include paths where one is a parent of
@@ -534,6 +548,30 @@ properly instead.
 The catkin manual recommends that all commands be written in lower case.
 """
 ),
+"UNGUARDED_TEST_DEPEND" : ("test_depend '%(pkg)s' used without if(CATKIN_ENABLE_TESTING)",
+"""\
+You have used a test dependency without properly guarding it by a
+if(CATKIN_ENABLE_TESTING) block. You must add a proper build dependency if
+you wish to use this package even if tests are disabled.
+"""
+),
+"UNGUARDED_TEST_CMD" : ("%(cmd)s() used without if(CATKIN_ENABLE_TESTING)",
+"""\
+You have used a test command without properly guarding it by a
+if(CATKIN_ENABLE_TESTING) block.
+"""
+),
+"INDENTATION" : ("line is not indented properly",
+"""\
+For better readability, each command should be placed on its own line.
+if() and foreach() bodies should be indented by one or more extra spaces.
+"""
+),
+"UNSORTED_LIST": ("list %(name)s should be sorted",
+"""\
+The catkin manual recommends that list element be kept in order.
+"""
+),
 }
 
 def msg(msg_id, **kwargs):
