@@ -28,18 +28,22 @@ class ChecksBuildTest(unittest.TestCase):
         self.assertEqual([ "MISSING_BUILD_INCLUDE_PATH" ], result)
 
 
-    @patch("os.path.isfile", lambda x: x == os.path.normpath("/mock-path/src/existing.cpp"))
+    @patch("os.path.isfile", lambda x: x in [os.path.normpath("/mock-path/src/a.cpp"), os.path.normpath("/mock-path/src/b.cpp")])
     def do_source_files(self):
         env = create_env()
         pkg = create_manifest("mock")
-        result = mock_lint(env, pkg, "add_executable(mock src/existing.cpp) add_library(mock_lib src/existing.cpp)", checks=cc.source_files)
+        result = mock_lint(env, pkg, "add_executable(mock src/a.cpp src/b.cpp) add_library(mock_lib src/a.cpp src/b.cpp)", checks=cc.source_files)
         self.assertEqual([], result)
-        result = mock_lint(env, pkg, "add_executable(mock ${CMAKE_CURRENT_SOURCE_DIR}/src/existing.cpp) add_library(mock_lib ${CMAKE_CURRENT_SOURCE_DIR}/src/existing.cpp)", checks=cc.source_files)
+        result = mock_lint(env, pkg, "add_executable(mock ${CMAKE_CURRENT_SOURCE_DIR}/src/a.cpp) add_library(mock_lib ${CMAKE_CURRENT_SOURCE_DIR}/src/a.cpp)", checks=cc.source_files)
         self.assertEqual([], result)
         result = mock_lint(env, pkg, "add_executable(mock src/missing.cpp)", checks=cc.source_files)
         self.assertEqual([ "MISSING_FILE" ], result)
         result = mock_lint(env, pkg, "add_library(mock src/missing.cpp)", checks=cc.source_files)
         self.assertEqual([ "MISSING_FILE" ], result)
+        result = mock_lint(env, pkg, "add_executable(mock src/b.cpp src/a.cpp)", checks=cc.source_files)
+        self.assertEqual([ "UNSORTED_LIST" ], result)
+        result = mock_lint(env, pkg, "add_library(mock src/b.cpp src/a.cpp)", checks=cc.source_files)
+        self.assertEqual([ "UNSORTED_LIST" ], result)
 
 
     @patch("os.path.isdir", lambda x: x == os.path.normpath("/mock-path/in_package"))
@@ -210,6 +214,21 @@ class ChecksBuildTest(unittest.TestCase):
             """,
         checks=cc.depends)
         self.assertEqual([], result)
+        pkg = create_manifest("mock", build_depends=[ "first_pkg", "second_pkg" ])
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED COMPONENTS first_pkg second_pkg)
+            """,
+        checks=cc.depends)
+        self.assertEqual([], result)
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED COMPONENTS second_pkg first_pkg)
+            """,
+        checks=cc.depends)
+        self.assertEqual([ "UNSORTED_LIST" ], result)
 
 
     @patch("os.path.isfile", lambda x: x == os.path.normpath("/mock-path/src/mock.cpp"))
@@ -645,6 +664,23 @@ class ChecksBuildTest(unittest.TestCase):
             """,
         checks=cc.exports)
         self.assertEqual([ "MISSING_BUILD_INCLUDE", "AMBIGUOUS_BUILD_INCLUDE" ], result)
+        pkg = create_manifest("mock", build_depends=[ "first_pkg", "second_pkg" ], run_depends=[ "first_pkg", "second_pkg" ])
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED COMPONENTS first_pkg second_pkg)
+            catkin_package(CATKIN_DEPENDS first_pkg second_pkg)
+            """,
+        checks=cc.exports)
+        self.assertEqual([], result)
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED COMPONENTS first_pkg second_pkg)
+            catkin_package(CATKIN_DEPENDS second_pkg first_pkg)
+            """,
+        checks=cc.exports)
+        self.assertEqual([ "UNSORTED_LIST" ], result)
 
 
     @patch("os.path.isfile", lambda x: x == os.path.normpath("/mock-path/config.xml"))
@@ -697,7 +733,7 @@ class ChecksBuildTest(unittest.TestCase):
             find_package(other_catkin REQUIRED)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
-            catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
+            catkin_package(CATKIN_DEPENDS message_runtime other_catkin)
             """,
         checks=cc.message_generation)
         self.assertEqual([], result)
@@ -710,7 +746,7 @@ class ChecksBuildTest(unittest.TestCase):
             find_package(other_catkin REQUIRED)
             generate_messages(DEPENDENCIES other_catkin)
             add_message_files(FILES mock.msg)
-            catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
+            catkin_package(CATKIN_DEPENDS message_runtime other_catkin)
             """,
         checks=cc.message_generation)
         self.assertEqual([ "ORDER_VIOLATION" ], result)
@@ -721,7 +757,7 @@ class ChecksBuildTest(unittest.TestCase):
             find_package(catkin REQUIRED)
             find_package(message_generation REQUIRED)
             find_package(other_catkin REQUIRED)
-            catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
+            catkin_package(CATKIN_DEPENDS message_runtime other_catkin)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
             """,
@@ -736,7 +772,7 @@ class ChecksBuildTest(unittest.TestCase):
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
             find_package(catkin REQUIRED)
-            catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
+            catkin_package(CATKIN_DEPENDS message_runtime other_catkin)
             """,
         checks=cc.message_generation)
         self.assertEqual([ "CATKIN_ORDER_VIOLATION", "CATKIN_ORDER_VIOLATION" ], result)
@@ -761,7 +797,7 @@ class ChecksBuildTest(unittest.TestCase):
             find_package(message_generation REQUIRED)
             find_package(other_catkin REQUIRED)
             add_message_files(FILES mock.msg)
-            catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
+            catkin_package(CATKIN_DEPENDS message_runtime other_catkin)
             """,
         checks=cc.message_generation)
         self.assertEqual([ "MISSING_GENERATE_MSG" ], result)
@@ -773,7 +809,7 @@ class ChecksBuildTest(unittest.TestCase):
             find_package(message_generation REQUIRED)
             find_package(other_catkin REQUIRED)
             generate_messages(DEPENDENCIES other_catkin)
-            catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
+            catkin_package(CATKIN_DEPENDS message_runtime other_catkin)
             """,
         checks=cc.message_generation)
         self.assertEqual([ "UNUSED_GENERATE_MSG" ], result)
@@ -812,7 +848,7 @@ class ChecksBuildTest(unittest.TestCase):
             find_package(other_catkin REQUIRED)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
-            catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
+            catkin_package(CATKIN_DEPENDS message_runtime other_catkin)
             """,
         checks=cc.message_generation)
         self.assertEqual([ "UNCONFIGURED_BUILD_DEPEND" ], result)
@@ -824,7 +860,7 @@ class ChecksBuildTest(unittest.TestCase):
             find_package(catkin REQUIRED COMPONENTS message_generation)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
-            catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
+            catkin_package(CATKIN_DEPENDS message_runtime other_catkin)
             """,
         checks=cc.message_generation)
         self.assertEqual([ "MISSING_DEPEND", "UNCONFIGURED_MSG_DEPEND", "MISSING_MSG_DEPEND", "MISSING_MSG_DEPEND" ], result)
